(find-config app-id-or-bucket)Find the config map for bucket-name or app-id
Find the config map for bucket-name or app-id
(get-alias base-url)Returns the instance alias for a given domain or the same domain if no alias if found
Returns the instance alias for a given domain or the same domain if no alias if found
(get-bucket-name url)Extracts the bucket name from an upload domain url: https://akvoflow-1.s3.amazonaws.com => akvoflow-1
Extracts the bucket name from an upload domain url: https://akvoflow-1.s3.amazonaws.com => akvoflow-1
(get-criteria bucket-name surveyId)Returns a map of upload configuration criteria
Returns a map of upload configuration criteria
(get-domain base-url)Returns the instance domain for a given base-url
Returns the instance domain for a given base-url
(set-config! path)Resets the value of configs and alias maps based on the appengine-web.xml files
Resets the value of configs and alias maps based on the appengine-web.xml files
(set-settings! path)Resets the value of settings reading the new values from the file path
Resets the value of settings reading the new values from the file path
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |