akvo.commons.jwt


jwt-tokenclj

(jwt-token req)

Get the jwt token from the authorization header of the request

Get the jwt token from the authorization header of the request
sourceraw docstring

rsa-keyclj

(rsa-key cert)
(rsa-key cert n)

Parse an RSA certificate string

Parse an RSA certificate string
sourceraw docstring

verified-claimsclj

(verified-claims token verifier issuer opts)

Parses and verifies jwt token and returns the claims if the token is verified, otherwise nil. Throws ParseException if the token can not be parsed.

Parses and verifies jwt token and returns the claims if the token
is verified, otherwise nil. Throws ParseException if the token can
not be parsed.
sourceraw docstring

wrap-jwt-claimsclj

(wrap-jwt-claims handler rsa-key issuer)
(wrap-jwt-claims handler rsa-key issuer opts)

Verifies the jwt token using the cert string and associates the claims to the request if it can be verified. Takes an optional opts map with keys

:iat-interval [before after] Compare the 'issued at' time (iat) with the interval [now - before, now + after] and consider the token valid only if the iat falls within this interval (in seconds)

Verifies the jwt token using the cert string and associates the
claims to the request if it can be verified. Takes an optional opts
map with keys

:iat-interval [before after] Compare the 'issued at' time (iat) with
the interval [now - before, now + after] and consider the token
valid only if the iat falls within this interval (in seconds)
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries